# Copyright (c) 2013 Dirk Jagdmann <doj@cubic.org>

# This software is provided 'as-is', without any express or implied
# warranty. In no event will the authors be held liable for any damages
# arising from the use of this software.

# Permission is granted to anyone to use this software for any purpose,
# including commercial applications, and to alter it and redistribute it
# freely, subject to the following restrictions:

#     1. The origin of this software must not be misrepresented; you
#        must not claim that you wrote the original software. If you use
#        this software in a product, an acknowledgment in the product
#        documentation would be appreciated but is not required.

#     2. Altered source versions must be plainly marked as such, and
#        must not be misrepresented as being the original software.

#     3. This notice may not be removed or altered from any source
#        distribution.

# $Id: IIF.pm 7554 2013-12-22 23:37:24Z doj $

package Quickbooks::IIF;

use Carp;
use strict;

my $trns = '';

sub init
{
    $trns = '';
    return 1;
}

sub addrecord
{
    my ($h) = @_;
    # check parameter
    unless (ref($h) eq 'HASH') { carp 'parameter is not a hash reference'; return }
    # check if hash contains all keys
    foreach my $k (qw(TransactionID Timestamp PayPalAccount QuickbooksAccount PayerDisplayName NetAmount GrossAmount Title))
    {
	unless (exists $h->{$k}) { carp "missing $k"; return }
	unless (length($h->{$k}) > 0) { carp "$k has empty value"; return }
    }

    my $gross = - $h->{GrossAmount};
    my $date = PayPal::str2local_date($h->{Timestamp});

    if ($trns eq '') {
	$trns = <<'EOT';
!TRNS	TRNSID	DATE	ACCNT	NAME	AMOUNT	MEMO
!SPL	SPLID	DATE	ACCNT	NAME	AMOUNT	MEMO
!ENDTRNS
EOT
    }

    $trns .= <<"EOF";
TRNS	"$h->{TransactionID}"	"$date"	"$h->{PayPalAccount}"	"$h->{PayerDisplayName}"	$h->{NetAmount}	"$h->{Title} $h->{Payer}"
SPL	"$h->{TransactionID}"	"$date"	"$h->{QuickbooksAccount}"	"$h->{PayerDisplayName}"	$gross	"$h->{Title} $h->{Payer}"
EOF
    if ($h->{FeeAmount} != 0) {
	my $fee = - $h->{FeeAmount};
	$trns .= <<"EOF";
SPL	"$h->{TransactionID}"	"$date"	"$h->{QuickbooksAccount}"	"$h->{PayerDisplayName}"	$fee	"$h->{Title} PayPal Fee"
EOF
    }
    $trns .= "ENDTRNS\n";

    return 1;
}

sub save
{
    my ($iif) = @_;
    return unless length($iif) > 0;
    return 0 unless length($trns) > 0;

    open(my $out, '>', $iif) or croak "could not open $iif for writing: $!";
    print $out $trns;
    close($out);

    return 1;
}

1;
